%define         majornum        2
%define         libname         %mklibname %{name} %{majornum}
%define         develname       %mklibname %{name} -d

%define         arkmajor        1
%define         cvmajor         2
%define         cvsmajor        2
%define         idasmajor       1
%define         idamajor        2
%define         kinmajor        2
%define         cpmajor         0
%define         nvecmajor       2


Name:           sundials
Version:        2.7.0
Release:        %mkrel 1
Summary:        Nonlinear, differential and algebraic equation solvers
License:        BSD
Group:          Sciences/Computer science

URL:            https://computation.llnl.gov/projects/sundials
Source0:        https://computation.llnl.gov/projects/sundials/download/%{name}-%{version}.tar.gz
#fix hardcoded install in "lib"
Patch0:         sundials-2.7.0-libdir.patch

BuildRequires:  cmake
BuildRequires:  gcc-gfortran
%ifarch %{ix86} x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  openmpi-devel
BuildRequires:  lapack-devel
BuildRequires:  blas-devel
BuildRequires:  suitesparse-devel
BuildRequires:  python

Requires:       %{libname} = %{version}-%{release}

%description
SUNDIALS is a SUite of Nonlinear and DIfferential/ALgebraic equation
Solvers implemented with the goal of providing robust time integrators
and nonlinear solvers that can easily be incorporated into existing
simulation codes. The primary design goals are to require minimal
information from the user, allow users to easily supply their own data
structures underneath the packages, and allow for easy incorporation
of user-supplied linear solvers and preconditioners. The main
numerical operations performed in these codes are operations on data
vectors, and the codes have been written in terms of interfaces to
these vector operations. The result of this design is that users can
relatively easily provide their own data structures to the solvers by
telling the solver about their structures and providing the required
operations on them. The codes also come with default vector structures
with pre-defined operation implementations for serial, shared-memory
parallel (openMP and PThreads), and distributed memory parallel (MPI)
environments in case a user prefers not to supply their own
structures. In addition, all parallelism is contained within
specific vector operations (norms, dot products, etc.). No other
operations within the solvers require knowledge of parallelism. Thus,
using a solver in parallel consists of using a parallel vector
implementation, either one provided with SUNDIALS or the user’s own
parallel vector structure, underneath the solver.



%package -n %{libname}
Summary:        The SUNDIALS libraries
Group:          System/Libraries

%description -n %{libname}
%{summary}.


%package -n %{develname}
Summary:        Development files for the SUNDIALS libraries
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       sundials-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
%{summary}.


%prep

%setup -q 
%autopatch -p1
export LDFLAGS="-lm"
export libdir=%{_lib}
%cmake .. \
          -DCMAKE_INSTALL_LIBSUFFIX="%{_lib}" \
          -DFCMIX_ENABLE:BOOL=ON \
          -DLAPACK_ENABLE:BOOL=ON \
          -DKLU_ENABLE:BOOL=ON \
          -DKLU_INCLUDE_DIR:PATH=%{_includedir}/suitesparse \
          -DKLU_LIBRARY_DIR:PATH=%{_libdir} \
          -DMPI_ENABLE:BOOL=ON \
          -DOPENMP_ENABLE:BOOL=ON \
          -DPTHREADS_ENABLE:BOOL=ON \
          -DEXAMPLES_INSTALL_PATH=%{_datadir}/%{name}/examples

%build
%make_build -C build




%install
%make_install -C build


#remove la and static files
find %{buildroot}%{_libdir} -name *.la -delete
find %{buildroot}%{_libdir} -name *.a -delete


%files
%doc LICENSE README
%{_datadir}/sundials


%files -n %{libname}
%{_libdir}/libsundials_arkode.so.%{arkmajor}{,.*}
%{_libdir}/libsundials_cvode.so.%{cvmajor}{,.*}
%{_libdir}/libsundials_cvodes.so.%{cvsmajor}{,.*}
%{_libdir}/libsundials_ida.so.%{idamajor}{,.*}
%{_libdir}/libsundials_idas.so.%{idasmajor}{,.*}
%{_libdir}/libsundials_kinsol.so.%{kinmajor}{,.*}
%{_libdir}/libsundials_nvec*.so.%{nvecmajor}{,.*}
%{_libdir}/libsundials_fnvec*.so.%{nvecmajor}{,.*}

%files -n %{develname}
%{_includedir}/*/*.h
%{_libdir}/libsundials_*.so




%changelog
* Sun Apr 23 2017 eatdirt <eatdirt> 2.7.0-1.mga6
+ Revision: 1097145
- imported package sundials

